import { Router, ActivatedRoute } from '@angular/router';
import { ReplaySubject } from 'rxjs/ReplaySubject';
import { BaseComponent } from './base.component';
import { Item } from '../../shared/data/item';
import { BaseCRUDServiceInterface } from '../shared/base-interface.service';
import { BaseFilter } from '../shared/base.filter';
import { MessageService } from '../../shared/service/message.service';
import { ToolbarService } from '../../shared/service/toolbar.service';
import { TableViewService } from '../../shared/service/tableview.service';
import { GeneralUtils } from '../../shared/service/general-utils.service';
import { PageStatus } from '../../shared/global.constants';
/**
 * Clase base para implementar listados de elementos con paginación. Provee el 95% de la funcionalidad necesaria.
 */
export declare abstract class BaseListComponent extends BaseComponent {
    displayFilter: boolean;
    breadcrumb: any[];
    items: Item[];
    totalItems: number;
    autoQuerySubject: ReplaySubject<BaseFilter>;
    protected filter: BaseFilter;
    protected customToolbarActions: any;
    protected messages: Map<PageStatus, string>;
    protected activatedRoute: ActivatedRoute;
    protected router: Router;
    protected dataService: BaseCRUDServiceInterface;
    protected paramsDataService: any;
    protected messageService: MessageService;
    protected tableViewService: TableViewService;
    protected generalUtils: GeneralUtils;
    /** Constructor de la clase. */
    constructor(dataService: BaseCRUDServiceInterface, messageService: MessageService, activatedRoute: ActivatedRoute, router: Router, toolbarService?: ToolbarService, componentId?: string, generalUtils?: GeneralUtils, tableViewService?: TableViewService);
    /** Prepara el valor de los campos del filtro antes de realizar la consulta. */
    abstract prepareDataForSubmit(): void;
    /** Determina si se debe autoejecutar la búsqueda en función de si nos envían el parametro query=true en la URL */
    init(filter: BaseFilter): void;
    /** Resetea la página como si entráramos de nuevo en ella. */
    resetData(): void;
    /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de elementos a mostrar por página */
    onNewPageSize(pageSize: number): void;
    /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de página a mostrar */
    onPageChange(page: number): void;
    /** Cuando algún componente hijo como el filtro nos comunique que se debe realizar la búsqueda */
    onSearch(filter: BaseFilter, count?: boolean): void;
    /** Cuando resetean el filtro de busqueda */
    onReset(filter: BaseFilter): void;
    /** Cuando se pulsa un botón del toolbar */
    onToolbarButtonPressed(button: string): void;
    handlePrint(): void;
    handleExport(): void;
    handleNew(): void;
    /**cualquier otra accion que no sea la típica de guardar o eliminar */
    otherAction(button: string): void;
    initializeSearch(count: boolean): void;
    /** Marca el estado como "búsqueda finalizada" (PageStatus.FinishSearch). */
    finishSearch(): void;
    /** Realiza la búsqueda filtrada de elementos. */
    search(count?: boolean): void;
    /** Realiza la búsqueda filtrada de elementos. */
    count(): void;
    /** Muestra el filtro de búsqueda. */
    showFilter(): void;
    /** Oculta el filtro de búsqueda. */
    hideFilter(): void;
}
