import { SimpleChange, EventEmitter } from '@angular/core';
import { BaseComponent } from './base.component';
import { Item } from '../../shared/data/item';
import { MessageService } from '../../shared/service/message.service';
import { ToolbarService } from '../../shared/service/toolbar.service';
import { GeneralUtils } from '../../shared/service/general-utils.service';
import { FormType } from '../../shared/global.constants';
/**
 */
export declare abstract class BaseSublistComponent extends BaseComponent {
    protected generalUtils: GeneralUtils;
    protected messageService: MessageService;
    lista: Item[];
    displayInnerForm: boolean;
    modeInnerForm: FormType;
    itemSelected: Item;
    tableView: any;
    parent: Item;
    parentField: string;
    initLoad: boolean;
    itemsPreloaded: Item[];
    femenino: boolean;
    forceReload: EventEmitter<any>;
    reloadFromServer: boolean;
    protected loadedParentId: number;
    protected selectedItems: number[];
    constructor(generalUtils: GeneralUtils, messageService: MessageService, toolbarService?: ToolbarService, componentId?: string);
    /** Función para mostrar el formulario del item. Podría ser via Dialog emergente, llamando a otro route, etc.. */
    abstract gotoForm(data?: any): any;
    /** Función que la clase que extienda esta clase debe implementar como cargar la lista */
    abstract callLoadItems(parent: Item): any;
    /** Función que la clase que extienda esta clase debe implementar como eliminar los elementos seleccionados */
    abstract callDeleteItems(parent: Item, items: number[]): any;
    /** Función que la clase que extienda esta clase debe implementar como guardar un elemento */
    abstract callSaveItem(parent: Item, item: Item, mode: FormType): any;
    /** Controlamos si la propiedad initLoad cambia a true para cargar la lista de documentos */
    ngOnChanges(changes: {
        [propKey: string]: SimpleChange;
    }): void;
    /** Nos presionan algún botón del toolbar */
    onToolbarButtonPressed(button: string): void;
    /** Cualquier otra accion que no sea la típica de guardar o eliminar */
    otherAction(action: string): void;
    /** Nos checkean algún item del listado */
    onItemChecked(selectedItems: number[]): void;
    /** nos piden cerrar el formulario */
    closeForm(doc: any): void;
    /** Cargamos la lista de documentos del usuario */
    loadItems(): void;
    /** Elimina los documentos seleccionados */
    deleteItems(items: any[]): void;
    /** Inserta o actualiza el documento */
    saveItem(item: Item): void;
    /** Función para hacer algo después de haber guardado */
    postSave(result: Item): void;
    /** Función para hacer algo después de haber eliminado los elementos seleccionados */
    postDelete(result: any): void;
}
