"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var datatable_1 = require("primeng/components/datatable/datatable");
/**
 * Clase base de los componentes TableView
 */
var BaseTableViewComponent = (function () {
    function BaseTableViewComponent(domainCachedService, tableViewService) {
        var _this = this;
        this.totalItems = 0;
        this.onPageChange = new core_1.EventEmitter();
        this.csvSeparator = ',';
        this.domainCachedService = domainCachedService;
        this.tableViewService = tableViewService;
        this.subscriptionMessages = tableViewService.observableExport.subscribe(function (message) {
            _this.exportCSV();
        });
    }
    BaseTableViewComponent.prototype.exportCSV = function () {
        var _this = this;
        var dt = this.dataTable;
        if (dt == null) {
            alert("Exportació no disponible");
            return;
        }
        var data = this.items;
        var csv = '';
        //headers
        for (var i = 0; i < dt.columns.length; i++) {
            if (dt.columns[i].field && !dt.columns[i].hidden) {
                csv += dt.columns[i].header || dt.columns[i].field;
                if (i < (dt.columns.length - 1)) {
                    csv += this.csvSeparator;
                }
            }
        }
        //body
        dt.value.forEach(function (record, i) {
            csv += '\n';
            for (var i_1 = 0; i_1 < dt.columns.length; i_1++) {
                if (dt.columns[i_1].field && !dt.columns[i_1].hidden) {
                    var cell = _this.getColumna(record, dt.columns[i_1].field) || dt.resolveFieldData(record, dt.columns[i_1].field);
                    if (cell == null) {
                        cell = '';
                    }
                    cell = cell.toString();
                    if (cell.indexOf(",") != -1) {
                        cell = "\"" + cell + "\"";
                    }
                    csv += cell;
                    if (i_1 < (dt.columns.length - 1)) {
                        csv += _this.csvSeparator;
                    }
                }
            }
        });
        var blob = new Blob(["\ufeff", csv], {
            type: 'text/csv;charset=utf-8;'
        });
        if (window.navigator.msSaveOrOpenBlob) {
            navigator.msSaveOrOpenBlob(blob, dt.exportFilename + '.csv');
        }
        else {
            var link = document.createElement("a");
            link.style.display = 'none';
            document.body.appendChild(link);
            if (link.download !== undefined) {
                link.setAttribute('href', URL.createObjectURL(blob));
                link.setAttribute('download', dt.exportFilename + '.csv');
                link.click();
            }
            else {
                csv = 'data:text/csv;charset=utf-8,' + csv;
                window.open(encodeURI(csv));
            }
            document.body.removeChild(link);
        }
    };
    BaseTableViewComponent.prototype.getDataTable = function () {
        return null;
    };
    BaseTableViewComponent.prototype.getColumna = function (record, field) {
        return null;
    };
    BaseTableViewComponent.prototype.getColumnaDominio = function (dominio, valor) {
        var domainMatch = dominio && dominio.find(function (obj) { return obj.value == valor; });
        if (domainMatch) {
            return domainMatch.label;
        }
        else if (valor) {
            return new String("??" + valor + "??");
        }
        return '';
    };
    BaseTableViewComponent.prototype.ngOnDestroy = function () {
        this.subscriptionMessages.unsubscribe();
    };
    BaseTableViewComponent.prototype.pageChanged = function (event) {
        console.log("pageChanged(" + event + ")");
        this.onPageChange.emit(event.page + 1);
    };
    BaseTableViewComponent.propDecorators = {
        "dataTable": [{ type: core_1.ViewChild, args: ['dataTable',] },],
        "totalItems": [{ type: core_1.Input },],
        "onPageChange": [{ type: core_1.Output },],
    };
    return BaseTableViewComponent;
}());
exports.BaseTableViewComponent = BaseTableViewComponent;
//# sourceMappingURL=base-tableview.component.js.map