"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var hql_1 = require("../shared/data/hql");
var index_1 = require("../../shared/index");
var message_service_1 = require("../../shared/service/message.service");
var developer_service_1 = require("../shared/service/developer.service");
/**
 * Clase que implementa la consulta de información con consultas HQL.
 */
var HQLComponent = (function () {
    /** Constructor de la clase. */
    function HQLComponent(developerService, formBuilder, messageService) {
        this.developerService = developerService;
        this.formBuilder = formBuilder;
        this.messageService = messageService;
        this.breadcrumb = [];
        this.messages = new Map();
    }
    /** Inicializa la ficha: define la validación. */
    /** Inicializa la ficha: define la validación. */
    HQLComponent.prototype.ngOnInit = /** Inicializa la ficha: define la validación. */
    function () {
        this.init();
        this.hqlControl = this.formBuilder.control('', [forms_1.Validators.required]);
        this.breadcrumb = [];
        this.breadcrumb.push({ label: 'Developer' });
        this.breadcrumb.push({ label: 'S/HQL' });
        this.messages.set(index_1.PageStatus.Init, "Introdueixi el S/HQL");
        this.messages.set(index_1.PageStatus.Searching, "Executant la consulta");
        this.messages.set(index_1.PageStatus.FinishSearch, "Consulta executada correctament");
    };
    /** Inicializa el componente. */
    /** Inicializa el componente. */
    HQLComponent.prototype.init = /** Inicializa el componente. */
    function () {
        this.status = index_1.PageStatus.Init;
        this.hql = hql_1.HQL.newObject();
        this.hql.reset();
    };
    /** Envía la consulta/ejecución de HQL. */
    /** Envía la consulta/ejecución de HQL. */
    HQLComponent.prototype.sendSHQL = /** Envía la consulta/ejecución de HQL. */
    function (esHQL, execute) {
        var _this = this;
        // Evitamos iniciar una nueva búsqueda cuando la anterior aún está en curso (p. ej., double click)
        if (this.status === index_1.PageStatus.Searching) {
            return;
        }
        this.status = index_1.PageStatus.Searching;
        //this._developerService.sendHQLTest()
        this.developerService.sendSHQL(esHQL, this.hql, execute)
            .subscribe(function (result) {
            _this.hql = result;
            _this.status = index_1.PageStatus.FinishSearch;
        }, function (error) {
            _this.status = index_1.PageStatus.Error;
            _this.messageService.sendMessage(new index_1.BitMessage("Error", error));
        });
    };
    /** Limpia la información de consulta/ejecución. */
    /** Limpia la información de consulta/ejecución. */
    HQLComponent.prototype.resetForm = /** Limpia la información de consulta/ejecución. */
    function () {
        this.init();
    };
    Object.defineProperty(HQLComponent.prototype, "searchInitiated", {
        /** Flag: la página está realizando la búsqueda. */
        get: /** Flag: la página está realizando la búsqueda. */
        function () { return this.status === index_1.PageStatus.Init; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HQLComponent.prototype, "searching", {
        /** Flag: la página está realizando la búsqueda. */
        get: /** Flag: la página está realizando la búsqueda. */
        function () { return this.status === index_1.PageStatus.Searching; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HQLComponent.prototype, "searchFinished", {
        /** Flag: la página ha finalizado la última búsqueda. */
        get: /** Flag: la página ha finalizado la última búsqueda. */
        function () { return this.status === index_1.PageStatus.FinishSearch; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HQLComponent.prototype, "diagnostic", {
        /** Información de debug. */
        get: /** Información de debug. */
        function () { return JSON.stringify(this.hql); },
        enumerable: true,
        configurable: true
    });
    HQLComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'hql',
                    template: "\n\n     <bit-header [noToolbar]=\"true\" [breadcrumb]=breadcrumb></bit-header>\n\n     <div class=\"panel panel-filtro\">\n       <div class=\"panel-heading\">\n         <i></i>&nbsp;&nbsp;&nbsp;HQL\n       </div>\n       <div class=\"panel-body\">\n           <form role=\"form\"> <!-- #f=\"ngForm\"-->\n           <div class=\"form-group\">\n             <div class=\"row\">\n                 <div class=\"col-xs-12\">\n                     <textarea class=\"form-control h-200\" id=\"hql\" name=\"hql\" [(ngModel)]=\"hql.hql\" [formControl]=\"hqlControl\"></textarea>\n                 </div>\n             </div>\n           </div>\n           </form>\n       </div>\n       <div class=\"panel-footer text-center\">\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" (click)=\"resetForm()\">Neteja&nbsp;&nbsp;<span class=\"glyphicon glyphicon-erase\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(false, false)\">Query SQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(true, false)\">Query HQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(true, true)\">Execute HQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-flash\"></span></button>\n         </div>\n       </div>\n     </div>\n\n     <div>\n           <span class=\"mensaje\" [hidden]=\"!hql.resultado\">{{hql.resultado}}</span> <!-- (!searchFinished || errorMessage)-->\n     </div>\n\n     <bit-footer [paginator]=\"false\" type=\"form\" [status]=\"status\" [messages]=\"messages\"></bit-footer>\n\n     <!--footer class=\"footer navbar-fixed-bottom\">\n         <ul class=\"navbar-right\">\n             <li>\n                 <span class=\"mensaje mensaje-informacion\" *ngIf=\"searchInitiated\"><i class=\"glyphicon glyphicon-info-sign\"></i>Introdueixi el HQL i premi \"Query\" o \"Execute\"</span>\n                 <span class=\"mensaje mensaje-informacion\" *ngIf=\"searching\">Cercant...</span>\n                 <span class=\"mensaje mensaje-error\" *ngIf=\"searchFinished && !errorMessage\"><i class=\"glyphicon glyphicon-alert\"></i>HQL executat</span>\n                 <span class=\"mensaje mensaje-error\" *ngIf=\"errorMessage\"><i class=\"glyphicon glyphicon-alert\"></i>{{errorMessage}}</span>\n             </li>\n         </ul>\n     </footer-->\n   "
                },] },
    ];
    /** @nocollapse */
    HQLComponent.ctorParameters = function () { return [
        { type: developer_service_1.DeveloperService, },
        { type: forms_1.FormBuilder, },
        { type: message_service_1.MessageService, },
    ]; };
    return HQLComponent;
}());
exports.HQLComponent = HQLComponent;
//# sourceMappingURL=hql.component.js.map