"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var primeng_1 = require("primeng/primeng");
var Observable_1 = require("rxjs/Observable");
var global_constants_1 = require("../global.constants");
var base_filter_1 = require("../../base/shared/base.filter");
/**
* Componenente que muestra un paginador en la sección footer.
**/
var BitFooterComponent = (function () {
    function BitFooterComponent() {
        this.mostrarAvisos = true;
        this.fixed = true;
        this.itemsPerPage = base_filter_1.BaseFilter.RESULTADOS_PAGE;
        this.onPageChange = new core_1.EventEmitter();
        this.onNewPageSize = new core_1.EventEmitter();
        this.baseItemsPerPage = base_filter_1.BaseFilter.RESULTADOS_PAGE;
    }
    BitFooterComponent.prototype.ngOnInit = function () {
        if (this.typeFooter == undefined) {
            this.typeFooter = "list";
        }
        if (this.paginator == undefined) {
            this.paginator = false;
        } //mensajes por defecto si no vienen definidos
        if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_LIST) {
            this.messages = new Map();
            this.messages.set(global_constants_1.PageStatus.Init, "Introdueixi els criteris de cerca i premi 'Cerca'");
            this.messages.set(global_constants_1.PageStatus.Searching, "Cercant...");
            this.messages.set(global_constants_1.PageStatus.FinishSearch, "No s'ha trobat cap dada amb les dades introduïdes");
        }
        else if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_FORM) {
            this.messages = new Map();
            this.messages.set(global_constants_1.PageStatus.Init, "Premi el botó Desa per actualitzar les dades");
            this.messages.set(global_constants_1.PageStatus.Searching, "Enviant la sol·licitud...");
            this.messages.set(global_constants_1.PageStatus.FinishSearch, "Dades actualitzades satisfactòriament");
        }
        else if (this.messages == undefined && this.typeFooter === BitFooterComponent.TYPE_BLANK) {
            console.log('the footer is BLANK!');
            this.messages = new Map();
        }
    };
    /**
    * Cuando tengamos la referncia al componente paginator nos suscribimos al observable para recibir la notificación
    * de que se ha realizado una autobúsqueda con una página y/o resultados por página diferente al estándar
    */
    /**
    * Cuando tengamos la referncia al componente paginator nos suscribimos al observable para recibir la notificación
    * de que se ha realizado una autobúsqueda con una página y/o resultados por página diferente al estándar
    */
    BitFooterComponent.prototype.ngAfterViewInit = /**
    * Cuando tengamos la referncia al componente paginator nos suscribimos al observable para recibir la notificación
    * de que se ha realizado una autobúsqueda con una página y/o resultados por página diferente al estándar
    */
    function () {
        var _this = this;
        this.autoQueryObs && this.autoQueryObs.subscribe(function (filter) {
            if (_this.pc) {
                _this.itemsPerPage = filter.resultados;
                _this.pc._rows = filter.resultados;
                _this.pc._first = (filter.pagina - 1) * _this.pc._rows;
                _this.pc.updatePageLinks();
            }
        });
    };
    /**
     * Escucharemos a cambios en las propiedades totalItems para actualizar el paginador con respecto a las páginas que mostramos
     */
    /**
     * Escucharemos a cambios en las propiedades totalItems para actualizar el paginador con respecto a las páginas que mostramos
     */
    BitFooterComponent.prototype.ngOnChanges = /**
     * Escucharemos a cambios en las propiedades totalItems para actualizar el paginador con respecto a las páginas que mostramos
     */
    function (changes) {
        var log = [];
        for (var propName in changes) {
            var changedProp = changes[propName];
            if (propName === 'totalItems') {
                this.totalItems = changedProp.currentValue;
                (changedProp.previousValue !== changedProp.currentValue) ? this.calculatePageLinkSize() : undefined; //recalculamos
            }
        }
    };
    /** Calcula el número de enlaces visibles en el paginador (en el rango entre 1 y 20). */
    /** Calcula el número de enlaces visibles en el paginador (en el rango entre 1 y 20). */
    BitFooterComponent.prototype.calculatePageLinkSize = /** Calcula el número de enlaces visibles en el paginador (en el rango entre 1 y 20). */
    function () {
        this.pageLinkSize = Math.ceil(this.totalItems / this.itemsPerPage);
        if (this.pageLinkSize < 1) {
            this.pageLinkSize = 1;
        }
        if (this.pageLinkSize > 20) {
            this.pageLinkSize = 20;
        }
    };
    /** Establece el número de página en la visualización de resultados. Se invoca cuando el usuario cambia el número de resultados a mostrar o cambia de página */
    /** Establece el número de página en la visualización de resultados. Se invoca cuando el usuario cambia el número de resultados a mostrar o cambia de página */
    BitFooterComponent.prototype.paginate = /** Establece el número de página en la visualización de resultados. Se invoca cuando el usuario cambia el número de resultados a mostrar o cambia de página */
    function (event) {
        console.log("Page changed to", event.page);
        if (event.rows !== this.itemsPerPage) {
            // han cambiado el número de elementos por página
            //notificamos que los elementos por pagina han cambiado
            this.onNewPageSize.emit(event.rows);
            this.itemsPerPage = event.rows;
            this.calculatePageLinkSize(); // recalculamos el número de enlaces de página
        }
        else {
            //notificamos a nuestro papa que la página ha cambiado
            this.onPageChange.emit(event.page + 1);
        }
    };
    BitFooterComponent.prototype.getStyle = function () {
        if (this.fixed) {
            return "footer navbar-fixed-bottom";
        }
        else {
            return "footer";
        }
    };
    Object.defineProperty(BitFooterComponent.prototype, "searchInitiated", {
        /** Flag: la página está realizando la búsqueda. */
        get: /** Flag: la página está realizando la búsqueda. */
        function () { return this.status === global_constants_1.PageStatus.Init; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "searching", {
        /** Flag: la página está realizando la búsqueda. */
        get: /** Flag: la página está realizando la búsqueda. */
        function () { return this.status === global_constants_1.PageStatus.Searching; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "searchFinished", {
        /** Flag: la página ha finalizado la última búsqueda. */
        get: /** Flag: la página ha finalizado la última búsqueda. */
        function () { return this.status === global_constants_1.PageStatus.FinishSearch; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "readOnly", {
        /** Flag: la página está en modo solo lectura */
        get: /** Flag: la página está en modo solo lectura */
        function () { return this.status == global_constants_1.PageStatus.ReadOnly; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "error", {
        /** Flag: la página ha finalizado con error */
        get: /** Flag: la página ha finalizado con error */
        function () { return this.status == global_constants_1.PageStatus.Error; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "foundResult", {
        /** Flag: encontrado resultado. */
        get: /** Flag: encontrado resultado. */
        function () { return (this.totalItems > 0); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "emptyResult", {
        /** Flag: no hay resultados. */
        get: /** Flag: no hay resultados. */
        function () { return (this.totalItems === 0); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "initMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.Init); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "searchingMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.Searching); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "finishMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.FinishSearch); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "readOnlyMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.ReadOnly); },
        enumerable: true,
        configurable: true
    });
    BitFooterComponent.TYPE_LIST = 'list';
    BitFooterComponent.TYPE_FORM = 'form';
    BitFooterComponent.TYPE_BLANK = 'blank';
    BitFooterComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'bit-footer',
                    template: "\n<footer [class]=\"getStyle()\">\n    <div>\n        <ul *ngIf=\"typeFooter === 'list'\" [hidden]=\"emptyResult\" class=\"paginas\">\n            <li><label>&nbsp;&nbsp;&nbsp;&nbsp;Nombre de resultats:</label></li>\n            <li class=\"valor\"><span>{{totalItems}}</span></li>\n            <li *ngIf=\"paginator\">\n                <!-- Hay un bug con pageLinkSize. Pese a recalcularlo bien cuando se selecciona otra ventana de resultados. El componenten no lo actualiza hasta cambiar de p\u00E1gina--> \n                <p-paginator #pc [rows]=\"itemsPerPage\" [totalRecords]=\"totalItems\" [pageLinkSize]=\"pageLinkSize\" [rowsPerPageOptions]=\"[baseItemsPerPage,baseItemsPerPage+10,baseItemsPerPage+20]\" (onPageChange)=\"paginate($event)\"></p-paginator>\n            </li>\n        </ul>\n        <ul class=\"navbar-right\">\n            <li>                    \n                <span class=\"mensaje mensaje-informacion\" *ngIf=\"searchInitiated\"><i class=\"glyphicon glyphicon-info-sign\"></i>{{initMessage}}</span>\n                <span class=\"mensaje mensaje-informacion\" *ngIf=\"searching\">{{searchingMessage}}</span>\n                <span class=\"mensaje mensaje-informacion\" *ngIf=\"readOnly\">{{readOnlyMessage}}</span>\n                <span class=\"mensaje mensaje-error\" *ngIf=\"!searching && (searchFinished && emptyResult)\"><i class=\"glyphicon glyphicon-alert\"></i>{{finishMessage}}</span>\n                <span class=\"mensaje mensaje-error\" *ngIf=\"error\"><i class=\"glyphicon glyphicon-alert\"></i>S'ha produ\u00EFt un error</span>\n                <bit-help></bit-help>\n            </li>\n        </ul>\n    </div>\n</footer>\n"
                },] },
    ];
    /** @nocollapse */
    BitFooterComponent.ctorParameters = function () { return []; };
    BitFooterComponent.propDecorators = {
        "pc": [{ type: core_1.ViewChild, args: ["pc",] },],
        "autoQueryObs": [{ type: core_1.Input },],
        "totalItems": [{ type: core_1.Input },],
        "paginator": [{ type: core_1.Input },],
        "mostrarAvisos": [{ type: core_1.Input },],
        "fixed": [{ type: core_1.Input },],
        "status": [{ type: core_1.Input },],
        "typeFooter": [{ type: core_1.Input, args: ["type",] },],
        "messages": [{ type: core_1.Input },],
        "onPageChange": [{ type: core_1.Output },],
        "onNewPageSize": [{ type: core_1.Output },],
    };
    return BitFooterComponent;
}());
exports.BitFooterComponent = BitFooterComponent;
//# sourceMappingURL=bit-footer.component.js.map