"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var toolbar_service_1 = require("../service/toolbar.service");
/**
* Componenente que muestra una barra de botones.
* @Input() componentId contiene el identificador del componente que contiene este toolbar. Es opcional en cuyo caso el valor será "BASE"
* @Output() onToolbarButtonPressed. El componente captura la pulsación de estos botones y envia un evento onToolbarButtonPressed con el nombre del
* botón pulsado.
**/
var BitToolbarComponent = (function () {
    function BitToolbarComponent(toolbarService) {
        this.toolbarOld = {};
        this.femenino = false;
        this.componentId = "BASE";
        this.otherActionsDropdown = false;
        this.accionesReclamacionDenuncia = false;
        this.onToolbarButtonPressed = new core_1.EventEmitter();
        this.toolbar = {};
        this.toolbarService = toolbarService;
    }
    BitToolbarComponent.prototype.ngAfterContentInit = function () {
        console.log("soy el ToolbarComponent " + this.componentId);
        this.registerObservable();
    };
    BitToolbarComponent.prototype.registerObservable = function () {
        var _this = this;
        this.toolbarSubscription = this.toolbarService.observableToolbar.subscribe(function (newToolbar) {
            if (!newToolbar) {
                return; // un evento sin toolbar, no hay nada que hacer
            }
            if (!_this.componentId) {
                // si no tenemos componentId somos el único toolbar en pantalla, lo aceptamos sí o sí
                _this.setToolbar(newToolbar);
            }
            else {
                // tenemos componentId, por lo que probablemente hay varios toolbar simultáneos en pantalla
                // comprobamos si el evento indica que ha cambiado el que nos interesa y, en caso contrario, lo ignoramos
                if (_this.componentId === newToolbar.componentId) {
                    _this.setToolbar(newToolbar);
                }
            }
        });
    };
    BitToolbarComponent.prototype.enable = function (button) {
        return this.toolbar[button] && this.toolbar[button].enable;
    };
    BitToolbarComponent.prototype.visible = function (button) {
        return this.toolbar[button] && this.toolbar[button].visible;
    };
    BitToolbarComponent.prototype.label = function (button, defaultLabel) {
        return (this.toolbar[button] && this.toolbar[button].label) || defaultLabel;
    };
    BitToolbarComponent.prototype.estilo = function (button, defaultValue) {
        return (this.toolbar[button] && this.toolbar[button].estilo) || defaultValue || "fa fa-balance-spinner";
    };
    BitToolbarComponent.prototype.showFilter = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.FILTER_BUTTON);
    };
    BitToolbarComponent.prototype.print = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.PRINT_BUTTON);
    };
    BitToolbarComponent.prototype.exportData = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.EXPORT_BUTTON);
    };
    BitToolbarComponent.prototype.newElement = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.NEW_BUTTON);
    };
    BitToolbarComponent.prototype.add = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.ADD_BUTTON);
    };
    BitToolbarComponent.prototype.save = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.SAVE_BUTTON);
    };
    BitToolbarComponent.prototype.delete = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent.DELETE_BUTTON);
    };
    BitToolbarComponent.prototype.otherAction = function (button) {
        this.onToolbarButtonPressed.emit(button.action);
    };
    BitToolbarComponent.prototype.ngOnDestroy = function () {
        this.toolbarSubscription.unsubscribe();
    };
    BitToolbarComponent.prototype.setToolbar = function (newToolbar) {
        this.toolbar = newToolbar;
        // calcular si las other actions deben mostrarse en desplegable
        // (se ha pedido asi y hay más de una)
        var otherActionsVisibles = 0;
        for (var key in this.toolbar) {
            if (this.toolbar[key].otherAction && this.toolbar[key].visible) {
                otherActionsVisibles++;
            }
        }
        this.mostrarOtherActionsEnDesplegable = this.otherActionsDropdown && otherActionsVisibles > 1;
    };
    BitToolbarComponent.FILTER_BUTTON = "filter";
    BitToolbarComponent.PRINT_BUTTON = "print";
    BitToolbarComponent.EXPORT_BUTTON = "export";
    BitToolbarComponent.NEW_BUTTON = "new";
    BitToolbarComponent.SAVE_BUTTON = "save";
    BitToolbarComponent.DELETE_BUTTON = "delete";
    BitToolbarComponent.ADD_BUTTON = "add";
    BitToolbarComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'bit-toolbar',
                    template: "\n<!-- acciones no estandar definidas din\u00E1micamente o muy particulares-->\n<!-- si otherActionsDropdown viene a true y hay m\u00E1s de una acci\u00F3n, se muestran como un desplegable, si no, todas las acciones en l\u00EDnea -->\n<div class=\"btn-group dropdown\" role=\"group\" *ngIf=\"mostrarOtherActionsEnDesplegable\">\n    <button type=\"button\" *ngIf=\"otherActionsDropdown\"\n        class=\"btn btn-dinamico btn-accion dropdown-toggle\" data-toggle=\"dropdown\"\n        aria-haspopup=\"true\" aria-expanded=\"false\">Accions&nbsp;&nbsp;<span class=\"fa fa-caret-right\"></span></button>\n    <div class=\"dropdown-menu desplegable-accion\">\n        <ng-container *ngFor=\"let button of (toolbar | otherToolbarAction)\">\n            <button type=\"button\" \n                *ngIf=\"button.visible\"\n                [disabled]=\"!button.enable\" (click)=\"otherAction(button)\" class=\"btn btn-dinamico btn-accion dropdown-item\"\n            ><span [class]=\"button.estilo?button.estilo:'fa fa-caret-right'\"></span>&nbsp;&nbsp;{{button.label}}</button>\n        </ng-container>\n    </div>\n</div>\n\n<!-- si otherActionsDropdown viene a false o solo hay una acci\u00F3n, se muestran una tras otra en l\u00EDnea -->\n<div class=\"btn-inline\" *ngIf=\"!mostrarOtherActionsEnDesplegable\">\n    <ng-container *ngFor=\"let button of (toolbar | otherToolbarAction)\">\n        <div *ngIf=\"button.visible\" class=\"btn-group\" role=\"group\">\n            <button type=\"button\" [disabled]=\"!button.enable\" (click)=\"otherAction(button)\" class=\"btn btn-dinamico btn-accion\">{{button.label}}&nbsp;&nbsp;<span [class]=\"button.estilo?button.estilo:'fa fa-caret'\"></span></button>\n        </div>\n    </ng-container>\n</div>\n\n<!-- acciones estandar -->\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('new')\">\n    <button type=\"button\" [disabled]=\"!enable('new')\" (click)=\"newElement()\" class=\"btn btn-danger\">{{label('new', (femenino?'Nova':'Nou'))}}&nbsp;&nbsp;<span [class]=\"estilo('new', 'fa fa-plus')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('add')\">\n    <button type=\"button\" [disabled]=\"!enable('add')\" (click)=\"add()\" class=\"btn btn-danger\">{{label('nova', 'Afegeix')}}&nbsp;&nbsp;<span [class]=\"estilo('add', 'fa fa-plus')\"></span></button>\n</div>\n<!--div class=\"btn-group\" role=\"group\" *ngIf=\"visible('filter')\">\n    <button type=\"button\" [disabled]=\"!enable('filter')\" (click)=\"showFilter()\" class=\"btn btn-transparent\">{{label('filter', 'Mostra filtre')}}&nbsp;&nbsp;<span [class]=\"estilo('filter', 'glyphicon glyphicon-search')\"></span></button>\n</div-->\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('print')\">\n    <button type=\"button\" [disabled]=\"!enable('print')\" (click)=\"print()\" class=\"btn btn-transparent\">{{label('print', 'Imprimeix')}}&nbsp;&nbsp;<span [class]=\"estilo('print', 'glyphicon glyphicon-print')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('export')\">\n    <button type=\"button\" [disabled]=\"!enable('export')\" (click)=\"exportData()\" class=\"btn btn-transparent\">{{label('export', 'Exporta')}}&nbsp;&nbsp;<span [class]=\"estilo('export', 'glyphicon glyphicon-file')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('save')\">\n    <button type=\"button\" [disabled]=\"!enable('save')\" (click)=\"save()\" class=\"btn btn-success\">{{label('save', 'Desa')}}&nbsp;&nbsp;<span [class]=\"estilo('save', 'glyphicon glyphicon-floppy-disk')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('delete')\">\n    <button type=\"button\" [disabled]=\"!enable('delete')\" (click)=\"delete()\" class=\"btn btn-transparent btn-transparent-danger\">{{label('delete', 'Elimina')}}&nbsp;&nbsp;<span [class]=\"estilo('delete', 'glyphicon glyphicon-remove')\"></span></button>\n</div>\n"
                },] },
    ];
    /** @nocollapse */
    BitToolbarComponent.ctorParameters = function () { return [
        { type: toolbar_service_1.ToolbarService, },
    ]; };
    BitToolbarComponent.propDecorators = {
        "toolbarOld": [{ type: core_1.Input, args: ["toolbar",] },],
        "femenino": [{ type: core_1.Input },],
        "componentId": [{ type: core_1.Input },],
        "otherActionsDropdown": [{ type: core_1.Input },],
        "accionesReclamacionDenuncia": [{ type: core_1.Input },],
        "onToolbarButtonPressed": [{ type: core_1.Output },],
    };
    return BitToolbarComponent;
}());
exports.BitToolbarComponent = BitToolbarComponent;
//# sourceMappingURL=bit-toolbar.component.js.map