"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var http_1 = require("@angular/common/http");
var Observable_1 = require("rxjs/Observable");
var error_1 = require("../data/error");
var locator_service_1 = require("./locator.service");
var message_service_1 = require("./message.service");
var general_utils_service_1 = require("./general-utils.service");
var HttpUtilsService = (function () {
    function HttpUtilsService(http, messageService, generalUtils) {
        this.http = http;
        this.messageService = messageService;
        this.generalUtils = generalUtils;
        //@Inject("API_URL") public apiUrl: string Falla con AOT
        var injector = locator_service_1.LocatorService.injector;
        console.log("API_URL :" + HttpUtilsService.API_URL);
        console.log("HttpUtilsSerive creado con API Url:" + this.apiUrl());
    }
    HttpUtilsService.prototype.handleError = function (error) {
        this.generalUtils.stopLoading();
        var customError = HttpUtilsService.getCustomError(error);
        this.messageService.sendError(customError);
        return Observable_1.Observable.throw(customError);
    };
    HttpUtilsService.getCustomError = function (error) {
        var lastUrlAcceded = error.url;
        var innerError;
        var customError;
        if (error.message &&
            (error.message.includes('Unexpected token < in JSON') //chrome
                || error.message.includes('JSON.parse: unexpected character at line 1 column 1') //firefox
                || error.message.includes('JSON.parse Error: Invalid character at position:1')) //explorer
        ) {
            console.log("Parece que hemos perdido la sesión");
            //customError = new CustomError(lastUrlAcceded, "S'ha detectat que s'ha perdut la sessió amb el servidor. És necessari que torni a autenticar-se en el sistema.\n Si no apareix la pàgina d'introducció d'usuari i contrasenya, per favor tanqui el navegador i torni a obrir l'aplicació.",
            //"S'ha detectat que s'ha perdut la sessió amb el servidor. És necessari que torni a autenticar-se en el sistema.\n Si no apareix la pàgina d'introducció d'usuari i contrasenya, per favor tanqui el navegador i torni a obrir l'aplicació.", undefined, true, null);
            HttpUtilsService.reloadPage();
            return;
        }
        try {
            innerError = JSON.parse(error.error);
        }
        catch (err) {
            innerError = error.error;
        }
        if (innerError && (innerError['notificacion'] || innerError['trazaError'])) {
            //el error es controlado del servidor
            customError = innerError;
        }
        else {
            //el error es un problema de comunicaciones o del propio cliente Angular
            if (error.status || error.status === 0) {
                //caso jetty o error controlado del servidor
                console.log("HTTP Error con status " + error.status);
                if (error.status >= 300 && error.status < 500) {
                    customError = new error_1.Error(lastUrlAcceded, "Error d'accés o de connexió: No s'ha trobat la informació sol·licitada", "Error de acceso o de conexión: No se ha encontrado la información solicitada", undefined, true, null);
                }
                else {
                    customError = new error_1.Error(lastUrlAcceded, "S'ha produït un error en el servidor; per favor, esperi uns segons i torni a realitzar la mateixa acció", "Se ha producido un error en el servidor; por favor, espere unos segundos y vuelva a realizar la misma acción", undefined, true, null);
                }
            }
            else {
                customError = new error_1.Error(lastUrlAcceded, error.message, error.message, error.error);
            }
        }
        return customError;
    };
    HttpUtilsService.reloadPage = function () {
        var currentUrl = window.location.href;
        console.log("current url " + currentUrl);
        var index = currentUrl.lastIndexOf(HttpUtilsService.CONTEXT_PATH);
        var newUrl;
        if (index != -1) {
            newUrl = currentUrl.substring(0, index + HttpUtilsService.CONTEXT_PATH.length);
        }
        else {
            newUrl = currentUrl;
        }
        console.log("new url " + newUrl);
        window.location.href = newUrl;
    };
    HttpUtilsService.prototype.getHttpPost = function (url, hqlRequest, emptyResponse) {
        var _this = this;
        if (emptyResponse === void 0) { emptyResponse = false; }
        console.log("calling url server via POST:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        var body = JSON.stringify(hqlRequest);
        var headers = new http_1.HttpHeaders().set('Content-Type', 'application/json');
        var vResponseType = emptyResponse ? 'text' : 'json';
        return this.http.post(this.apiUrl() + url, body, { headers: headers, responseType: vResponseType })
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.getHttpPut = function (url, hqlRequest) {
        var _this = this;
        console.log("calling url server via PUT:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        var body = JSON.stringify(hqlRequest);
        var headers = new http_1.HttpHeaders().set('Content-Type', 'application/json');
        return this.http.put(this.apiUrl() + url, body, { headers: headers })
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.getHttpDelete = function (url) {
        var _this = this;
        console.log("calling url server via DELETE:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        var headers = new http_1.HttpHeaders().set('Content-Type', 'application/json');
        return this.http.delete(this.apiUrl() + url, {
            headers: headers,
            responseType: 'text'
        })
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.getHttpGet = function (url) {
        var _this = this;
        console.log("calling url server via GET:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        return this.http.get(this.apiUrl() + url)
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.apiUrl = function () {
        return HttpUtilsService.API_URL;
    };
    HttpUtilsService.API_URL = "http://localhost:8081/api/services/";
    // TODO customizar por proyecto
    HttpUtilsService.CONTEXT_PATH = "bitcitafront";
    HttpUtilsService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    HttpUtilsService.ctorParameters = function () { return [
        { type: http_1.HttpClient, },
        { type: message_service_1.MessageService, },
        { type: general_utils_service_1.GeneralUtils, },
    ]; };
    return HttpUtilsService;
}());
exports.HttpUtilsService = HttpUtilsService;
exports.httpUtilsServiceInjectables = [
    { provide: HttpUtilsService,
        useClass: HttpUtilsService
    } /*,
        {   provide: "API_URL",
            useValue: API_URL
        }*/
];
//# sourceMappingURL=http-utils.service.js.map